<!--排查单位查询-筛选弹层-->
<template>
  <van-popup
    v-model="isShowPopup"
    round
    closeable
    position="top"
    :style="{ height: '42%' }"
  >
    <div class="query-search-popup">
      <div class="title">隐患档案查询</div>
      <van-form label-width="80px">
        <!--受检单位类型选择显示-->
        <template>
          <van-field
            readonly
            clickable
            name="picker"
            :value="customQueryPrams.type_"
            label="受检单位类型"
            placeholder="点击选择受检单位类型"
            @click="unitTypePicker = true"
          />
          <van-popup v-model="unitTypePicker" position="bottom" get-container="body">
            <van-picker
              show-toolbar
              :columns="unitsTypeOpt"
              @confirm="({text}) => {
                customQueryPrams.type_ = text;
                unitTypePicker = false ;
              }"
              @cancel="unitTypePicker = false"
            />
          </van-popup>
        </template>

        <van-field
          v-model="customQueryPrams.unit_name_"
          name="单位名称"
          label="单位名称"
          placeholder="请输入单位名称"
          clearable
        />

        <van-field
          v-model="customQueryPrams.name_"
          name="负责人姓名"
          label="负责人姓名"
          placeholder="请输入负责人姓名"
          clearable
        />

        <div class="search-btn">
          <van-button class="btn-left" block type="info" native-type="button" @click="searchData">查询</van-button>
          <van-button class="btn-right" block plain type="info" native-type="button" @click="resetData">重置
          </van-button>
        </div>
      </van-form>
    </div>
  </van-popup>
</template>

<script>
import moment from 'moment'

export default {
  name: 'QuerySearchPopup', // 排查单位查询-筛选弹层
  props: {
    // 是否展示弹层
    querySearchPopup: {
      default: false,
      type: Boolean
    },
    // 查询对象
    customQueryPrams: {
      default() {
        return {}
      },
      type: Object
    },
    // 受检单位配置数组对象
    unitsTypeOpt: {
      default() {
        return []
      },
      type: Array
    }
  },
  data() {
    return {
      unitTypePicker: false // 受检单位类型选择显示
    }
  },
  computed: {
    isShowPopup: {
      get() {
        return this.querySearchPopup
      },
      set(val) {
        this.$emit('update:querySearchPopup', val)
      }
    }
  },
  methods: {
    moment,

    // 查询列表数据（校验成功后）
    searchData() {
      this.$emit('searchData', this.customQueryPrams)
      this.isShowPopup = false // 关闭筛选弹层
    },

    // 重置数据
    resetData() {
      /*
      * 重置数据，从父组件找到 “customQueryPrams对象” 的原始结构
      * 因为 “customQueryPrams对象”是计算属性的return数据结构
      * 不能使 customQueryPrams对象地址值发生改变，因而进行循环赋值处理
      * */
      Object.keys(this.customQueryPrams).forEach(key => {
        this.customQueryPrams[key] = this.$parent.$options.data().customQueryPrams[key]
      })
      this.$emit('searchData', this.customQueryPrams)
      this.isShowPopup = false // 关闭筛选弹层
    }

  }
}
</script>

<style lang="scss" scoped>
.query-search-popup {
  display: flex;
  flex-direction: column;
  height: 100%;

  .title {
    width: 100%;
    box-sizing: border-box;
    padding: 130px 0 100px 0;
    display: flex;
    align-items: center;
    justify-content: center;
    font-size: 80px;
  }

  .van-form {
    flex: 1;
    position: relative;

    .search-btn {
      display: flex;
      position: absolute;
      bottom: 5%;
      width: 80%;
      transform: translateX(-50%);
      left: 50%;

      .van-button {

        &.btn-left {
          border-radius: 999px 0 0 999px;
        }

        &.btn-right {
          border-radius: 0 999px 999px 0;
        }

        .van-button__text {
          font-size: 65px;
        }
      }


    }
  }

}
</style>

